@@ -872,7 +872,7 @@ MsgList parseXML(const char *filename)
             const int start = index;
             index = contents.indexOf( delim, index + rx.matchedLength() );
             index = contents.indexOf( '>', index );
-            if ( !name.startsWith( "i18n-" ) )
+            if ( !name.startsWith( QLatin1String("i18n-") ) )
                 continue;
             const QString entity = contents.mid( start, index - start + 1 );
             MsgBlock block;
@@ -922,7 +922,7 @@ MsgList parseXML(const char *filename)
     QTextStream ts(contents.toUtf8(), QIODevice::ReadOnly);
     QXmlInputSource source( ts.device() );
     QXmlSimpleReader reader;
-    reader.setFeature( "http://trolltech.com/xml/features/report-start-end-entity", true);
+    reader.setFeature( "http://qt-project.org/xml/features/report-start-end-entity", true);
     reader.setContentHandler( &handler );
     reader.setLexicalHandler( &handler );
     reader.setDTDHandler( &handler );
